# Changelog

Cambios notables de Django Payments Chile

Formato basado en [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
y este proyecto se adhiere a [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- Klap
- Kushki
- Pagofacil
- Transbank WebPayPlus
- Transbank OnePay

## [2024.9.29]

- Cambios en Documentacion
- Nuevos providers para: **Flow, Khipu, Payku**

## [2024.9.23]

- Commit Inicial
